From 087faed899b9afab324aff7fa20e715c4f99eb4a Mon Sep 17 00:00:00 2001
From: Marco Nenciarini <marco.nenciarini@2ndQuadrant.it>
Date: Thu, 29 Jan 2015 12:18:47 +0100
Subject: [PATCH 1/3] public parse_filename_for_nontemp_relation

---
 src/backend/storage/file/reinit.c | 58 ---------------------------------------
 src/common/relpath.c              | 56 +++++++++++++++++++++++++++++++++++++
 src/include/common/relpath.h      |  2 ++
 3 files changed, 58 insertions(+), 58 deletions(-)

diff --git a/src/backend/storage/file/reinit.c b/src/backend/storage/file/reinit.c
index afd9255..02b5fee 100644
*** a/src/backend/storage/file/reinit.c
--- b/src/backend/storage/file/reinit.c
*************** static void ResetUnloggedRelationsInTabl
*** 28,35 ****
  									  int op);
  static void ResetUnloggedRelationsInDbspaceDir(const char *dbspacedirname,
  								   int op);
- static bool parse_filename_for_nontemp_relation(const char *name,
- 									int *oidchars, ForkNumber *fork);
  
  typedef struct
  {
--- 28,33 ----
*************** ResetUnloggedRelationsInDbspaceDir(const
*** 388,446 ****
  		fsync_fname((char *) dbspacedirname, true);
  	}
  }
- 
- /*
-  * Basic parsing of putative relation filenames.
-  *
-  * This function returns true if the file appears to be in the correct format
-  * for a non-temporary relation and false otherwise.
-  *
-  * NB: If this function returns true, the caller is entitled to assume that
-  * *oidchars has been set to the a value no more than OIDCHARS, and thus
-  * that a buffer of OIDCHARS+1 characters is sufficient to hold the OID
-  * portion of the filename.  This is critical to protect against a possible
-  * buffer overrun.
-  */
- static bool
- parse_filename_for_nontemp_relation(const char *name, int *oidchars,
- 									ForkNumber *fork)
- {
- 	int			pos;
- 
- 	/* Look for a non-empty string of digits (that isn't too long). */
- 	for (pos = 0; isdigit((unsigned char) name[pos]); ++pos)
- 		;
- 	if (pos == 0 || pos > OIDCHARS)
- 		return false;
- 	*oidchars = pos;
- 
- 	/* Check for a fork name. */
- 	if (name[pos] != '_')
- 		*fork = MAIN_FORKNUM;
- 	else
- 	{
- 		int			forkchar;
- 
- 		forkchar = forkname_chars(&name[pos + 1], fork);
- 		if (forkchar <= 0)
- 			return false;
- 		pos += forkchar + 1;
- 	}
- 
- 	/* Check for a segment number. */
- 	if (name[pos] == '.')
- 	{
- 		int			segchar;
- 
- 		for (segchar = 1; isdigit((unsigned char) name[pos + segchar]); ++segchar)
- 			;
- 		if (segchar <= 1)
- 			return false;
- 		pos += segchar;
- 	}
- 
- 	/* Now we should be at the end. */
- 	if (name[pos] != '\0')
- 		return false;
- 	return true;
- }
--- 386,388 ----
diff --git a/src/common/relpath.c b/src/common/relpath.c
index 66dfef1..83a1e3a 100644
*** a/src/common/relpath.c
--- b/src/common/relpath.c
*************** GetRelationPath(Oid dbNode, Oid spcNode,
*** 206,208 ****
--- 206,264 ----
  	}
  	return path;
  }
+ 
+ /*
+  * Basic parsing of putative relation filenames.
+  *
+  * This function returns true if the file appears to be in the correct format
+  * for a non-temporary relation and false otherwise.
+  *
+  * NB: If this function returns true, the caller is entitled to assume that
+  * *oidchars has been set to the a value no more than OIDCHARS, and thus
+  * that a buffer of OIDCHARS+1 characters is sufficient to hold the OID
+  * portion of the filename.  This is critical to protect against a possible
+  * buffer overrun.
+  */
+ bool
+ parse_filename_for_nontemp_relation(const char *name, int *oidchars,
+ 									ForkNumber *fork)
+ {
+ 	int			pos;
+ 
+ 	/* Look for a non-empty string of digits (that isn't too long). */
+ 	for (pos = 0; isdigit((unsigned char) name[pos]); ++pos)
+ 		;
+ 	if (pos == 0 || pos > OIDCHARS)
+ 		return false;
+ 	*oidchars = pos;
+ 
+ 	/* Check for a fork name. */
+ 	if (name[pos] != '_')
+ 		*fork = MAIN_FORKNUM;
+ 	else
+ 	{
+ 		int			forkchar;
+ 
+ 		forkchar = forkname_chars(&name[pos + 1], fork);
+ 		if (forkchar <= 0)
+ 			return false;
+ 		pos += forkchar + 1;
+ 	}
+ 
+ 	/* Check for a segment number. */
+ 	if (name[pos] == '.')
+ 	{
+ 		int			segchar;
+ 
+ 		for (segchar = 1; isdigit((unsigned char) name[pos + segchar]); ++segchar)
+ 			;
+ 		if (segchar <= 1)
+ 			return false;
+ 		pos += segchar;
+ 	}
+ 
+ 	/* Now we should be at the end. */
+ 	if (name[pos] != '\0')
+ 		return false;
+ 	return true;
+ }
diff --git a/src/include/common/relpath.h b/src/include/common/relpath.h
index a263779..9736a78 100644
*** a/src/include/common/relpath.h
--- b/src/include/common/relpath.h
*************** extern char *GetDatabasePath(Oid dbNode,
*** 52,57 ****
--- 52,59 ----
  
  extern char *GetRelationPath(Oid dbNode, Oid spcNode, Oid relNode,
  				int backendId, ForkNumber forkNumber);
+ extern bool parse_filename_for_nontemp_relation(const char *name,
+ 								int *oidchars, ForkNumber *fork);
  
  /*
   * Wrapper macros for GetRelationPath.  Beware of multiple
-- 
2.2.2

